from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rsquelch:
	"""Rsquelch commands group definition. 18 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rsquelch", core, parent)

	@property
	def ofLevel(self):
		"""ofLevel commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_ofLevel'):
			from .Rsquelch_.OfLevel import OfLevel
			self._ofLevel = OfLevel(self._core, self._base)
		return self._ofLevel

	@property
	def onLevel(self):
		"""onLevel commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_onLevel'):
			from .Rsquelch_.OnLevel import OnLevel
			self._onLevel = OnLevel(self._core, self._base)
		return self._onLevel

	@property
	def ofsQuality(self):
		"""ofsQuality commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ofsQuality'):
			from .Rsquelch_.OfsQuality import OfsQuality
			self._ofsQuality = OfsQuality(self._core, self._base)
		return self._ofsQuality

	@property
	def onsQuality(self):
		"""onsQuality commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_onsQuality'):
			from .Rsquelch_.OnsQuality import OnsQuality
			self._onsQuality = OnsQuality(self._core, self._base)
		return self._onsQuality

	@property
	def hysteresis(self):
		"""hysteresis commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_hysteresis'):
			from .Rsquelch_.Hysteresis import Hysteresis
			self._hysteresis = Hysteresis(self._core, self._base)
		return self._hysteresis

	@property
	def tlevel(self):
		"""tlevel commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tlevel'):
			from .Rsquelch_.Tlevel import Tlevel
			self._tlevel = Tlevel(self._core, self._base)
		return self._tlevel

	@property
	def signalQuality(self):
		"""signalQuality commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_signalQuality'):
			from .Rsquelch_.SignalQuality import SignalQuality
			self._signalQuality = SignalQuality(self._core, self._base)
		return self._signalQuality

	@property
	def llist(self):
		"""llist commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_llist'):
			from .Rsquelch_.Llist import Llist
			self._llist = Llist(self._core, self._base)
		return self._llist

	def clone(self) -> 'Rsquelch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rsquelch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rsquelch:
	"""Rsquelch commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rsquelch", core, parent)

	def get_so_time(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:SOTime \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.rsquelch.get_so_time() \n
		Defines the time period for which the audio signal has to be continuously unmuted (or muted) after the DUT has switched
		off (or on) the squelch. The search routine only returns a positive result for the squelch level if the audio signal
		quality is detected as continuously high (or low) over that period. \n
			:return: sq_observ_time: Range: 1 s to 20 s, Unit: s
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:SOTime?')
		return Conversions.str_to_float(response)

	def set_so_time(self, sq_observ_time: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:SOTime \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rsquelch.set_so_time(sq_observ_time = 1.0) \n
		Defines the time period for which the audio signal has to be continuously unmuted (or muted) after the DUT has switched
		off (or on) the squelch. The search routine only returns a positive result for the squelch level if the audio signal
		quality is detected as continuously high (or low) over that period. \n
			:param sq_observ_time: Range: 1 s to 20 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(sq_observ_time)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:SOTime {param}')

	def get_lvl_tolerance(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:LVLTolerance \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.rsquelch.get_lvl_tolerance() \n
		Defines the maximum deviation from the measured average audio signal level during the 'Squelch Observation Time' when the
		squelch is switched off at the DUT. \n
			:return: tolerance: Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:LVLTolerance?')
		return Conversions.str_to_float(response)

	def set_lvl_tolerance(self, tolerance: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:LVLTolerance \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rsquelch.set_lvl_tolerance(tolerance = 1.0) \n
		Defines the maximum deviation from the measured average audio signal level during the 'Squelch Observation Time' when the
		squelch is switched off at the DUT. \n
			:param tolerance: Unit: dB
		"""
		param = Conversions.decimal_value_to_str(tolerance)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:LVLTolerance {param}')

	# noinspection PyTypeChecker
	def get_extent(self) -> enums.SearchExtent:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:EXTent \n
		Snippet: value: enums.SearchExtent = driver.configure.afRf.measurement.searchRoutines.rsquelch.get_extent() \n
		No command help available \n
			:return: search_extent: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:EXTent?')
		return Conversions.str_to_scalar_enum(response, enums.SearchExtent)

	def set_extent(self, search_extent: enums.SearchExtent) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:EXTent \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.rsquelch.set_extent(search_extent = enums.SearchExtent.FULL) \n
		No command help available \n
			:param search_extent: No help available
		"""
		param = Conversions.enum_scalar_to_str(search_extent, enums.SearchExtent)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:RSQuelch:EXTent {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("marker", core, parent)

	# noinspection PyTypeChecker
	class DelaysStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Marker_2: int: Delay for marker 2 of the ARB file Range: -10 to 4000
			- Marker_3: int: Delay for marker 3 of the ARB file Range: -10 to 4000
			- Marker_4: int: Delay for marker 4 of the ARB file Range: -10 to 4000
			- Restart_Marker: int: Delay for marker event due to start of ARB file processing Range: 0 to n (depends on ARB file)"""
		__meta_args_list = [
			ArgStruct.scalar_int('Marker_2'),
			ArgStruct.scalar_int('Marker_3'),
			ArgStruct.scalar_int('Marker_4'),
			ArgStruct.scalar_int('Restart_Marker')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Marker_2: int = None
			self.Marker_3: int = None
			self.Marker_4: int = None
			self.Restart_Marker: int = None

	def get_delays(self) -> DelaysStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:MARKer:DELays \n
		Snippet: value: DelaysStruct = driver.source.afRf.generator.arb.marker.get_delays() \n
		Defines delay times for the generation of trigger signals relative to the marker events. All delay times are specified as
		number of samples. \n
			:return: structure: for return value, see the help for DelaysStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:ARB:MARKer:DELays?', self.__class__.DelaysStruct())

	def set_delays(self, value: DelaysStruct) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:MARKer:DELays \n
		Snippet: driver.source.afRf.generator.arb.marker.set_delays(value = DelaysStruct()) \n
		Defines delay times for the generation of trigger signals relative to the marker events. All delay times are specified as
		number of samples. \n
			:param value: see the help for DelaysStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AFRF:GENerator<Instance>:ARB:MARKer:DELays', value)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trace:
	"""Trace commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trace", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:SROutines:RSENsitivity:SQUality:TRACe \n
		Snippet: value: List[float] = driver.afRf.measurement.searchRoutines.rsensitivity.signalQuality.trace.fetch() \n
		Returns the y-values of the points in the RX sensitivity result diagram. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: sens_sign_quality: Comma-separated list of signal quality values Unit: dB"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:AFRF:MEASurement<Instance>:SROutines:RSENsitivity:SQUality:TRACe?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:AFRF:MEASurement<Instance>:SROutines:RSENsitivity:SQUality:TRACe \n
		Snippet: value: List[float] = driver.afRf.measurement.searchRoutines.rsensitivity.signalQuality.trace.read() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: sens_sign_quality: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:AFRF:MEASurement<Instance>:SROutines:RSENsitivity:SQUality:TRACe?', suppressed)
		return response



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Types import DataType
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Base:
	"""Base commands group definition. 4 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("base", core, parent)

	@property
	def latest(self):
		"""latest commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_latest'):
			from .Base_.Latest import Latest
			self._latest = Latest(self._core, self._base)
		return self._latest

	# noinspection PyTypeChecker
	class AllStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Date: List[str]: Date of the calibration as string
			- Time: List[str]: Time of the calibration as string
			- Type_Py: List[enums.CalibType]: FSCorrection | CALibration | OGCal Type of the calibration FSCorrection Correction performed in factory or service CALibration Verification in the factory OGCal Verification by the service (outgoing calibration)"""
		__meta_args_list = [
			ArgStruct('Date', DataType.StringList, None, False, True, 1),
			ArgStruct('Time', DataType.StringList, None, False, True, 1),
			ArgStruct('Type_Py', DataType.EnumList, enums.CalibType, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Date: List[str] = None
			self.Time: List[str] = None
			self.Type_Py: List[enums.CalibType] = None

	def get_all(self) -> AllStruct:
		"""SCPI: CALibration:BASE:ALL \n
		Snippet: value: AllStruct = driver.calibration.base.get_all() \n
		Queries the stored calibration information. A comma-separated list is returned, containing three parameters per
		calibration, as described below. \n
			:return: structure: for return value, see the help for AllStruct structure arguments.
		"""
		return self._core.io.query_struct('CALibration:BASE:ALL?', self.__class__.AllStruct())

	# noinspection PyTypeChecker
	class AcFileStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Type_Py: str: Name of the correction file as string
			- Date: str: Creation date as string"""
		__meta_args_list = [
			ArgStruct.scalar_str('Type_Py'),
			ArgStruct.scalar_str('Date')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Type_Py: str = None
			self.Date: str = None

	def get_ac_file(self) -> AcFileStruct:
		"""SCPI: CALibration:BASE:ACFile \n
		Snippet: value: AcFileStruct = driver.calibration.base.get_ac_file() \n
		Query name and creation date of the currently active RF path correction file. Possible result: 'Factory Default',
		'2016-09-28' \n
			:return: structure: for return value, see the help for AcFileStruct structure arguments.
		"""
		return self._core.io.query_struct('CALibration:BASE:ACFile?', self.__class__.AcFileStruct())

	def clone(self) -> 'Base':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Base(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rf:
	"""Rf commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rf", core, parent)

	# noinspection PyTypeChecker
	def get_pemphasis(self) -> enums.PreDeEmphasis:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:FILTer:RF:PEMPhasis \n
		Snippet: value: enums.PreDeEmphasis = driver.source.afRf.generator.filterPy.rf.get_pemphasis() \n
		Configures the pre-emphasis filter. \n
			:return: preemphasis: OFF | T50 | T75 | T750 OFF Filter disabled T50, T75, T750 Time constant 50 µs / 75 µs / 750 µs
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:FILTer:RF:PEMPhasis?')
		return Conversions.str_to_scalar_enum(response, enums.PreDeEmphasis)

	def set_pemphasis(self, preemphasis: enums.PreDeEmphasis) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:FILTer:RF:PEMPhasis \n
		Snippet: driver.source.afRf.generator.filterPy.rf.set_pemphasis(preemphasis = enums.PreDeEmphasis.OFF) \n
		Configures the pre-emphasis filter. \n
			:param preemphasis: OFF | T50 | T75 | T750 OFF Filter disabled T50, T75, T750 Time constant 50 µs / 75 µs / 750 µs
		"""
		param = Conversions.enum_scalar_to_str(preemphasis, enums.PreDeEmphasis)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:FILTer:RF:PEMPhasis {param}')

	# noinspection PyTypeChecker
	def get_hpass(self) -> enums.HighpassFilter:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:FILTer:RF:HPASs \n
		Snippet: value: enums.HighpassFilter = driver.source.afRf.generator.filterPy.rf.get_hpass() \n
		Configures the highpass filter. \n
			:return: highpass_filter: OFF | F300 OFF Filter disabled F300 Cutoff frequency 300 Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:FILTer:RF:HPASs?')
		return Conversions.str_to_scalar_enum(response, enums.HighpassFilter)

	def set_hpass(self, highpass_filter: enums.HighpassFilter) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:FILTer:RF:HPASs \n
		Snippet: driver.source.afRf.generator.filterPy.rf.set_hpass(highpass_filter = enums.HighpassFilter.F300) \n
		Configures the highpass filter. \n
			:param highpass_filter: OFF | F300 OFF Filter disabled F300 Cutoff frequency 300 Hz
		"""
		param = Conversions.enum_scalar_to_str(highpass_filter, enums.HighpassFilter)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:FILTer:RF:HPASs {param}')

	# noinspection PyTypeChecker
	def get_lpass(self) -> enums.LowpassFilter:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:FILTer:RF:LPASs \n
		Snippet: value: enums.LowpassFilter = driver.source.afRf.generator.filterPy.rf.get_lpass() \n
		Configures the lowpass filter. \n
			:return: lowpass_filter: OFF | F3K | F4K | F15K OFF Filter disabled F3K, F4K, F15K Cutoff frequency 3 kHz / 4 kHz / 15 kHz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:FILTer:RF:LPASs?')
		return Conversions.str_to_scalar_enum(response, enums.LowpassFilter)

	def set_lpass(self, lowpass_filter: enums.LowpassFilter) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:FILTer:RF:LPASs \n
		Snippet: driver.source.afRf.generator.filterPy.rf.set_lpass(lowpass_filter = enums.LowpassFilter.F15K) \n
		Configures the lowpass filter. \n
			:param lowpass_filter: OFF | F3K | F4K | F15K OFF Filter disabled F3K, F4K, F15K Cutoff frequency 3 kHz / 4 kHz / 15 kHz
		"""
		param = Conversions.enum_scalar_to_str(lowpass_filter, enums.LowpassFilter)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:FILTer:RF:LPASs {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Span:
	"""Span commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("span", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.SpanMode:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN:MODE \n
		Snippet: value: enums.SpanMode = driver.configure.gprfMeasurement.spectrum.frequency.span.get_mode() \n
		Selects the measurement mode. \n
			:return: span_mode: FSWeep | ZSPan FSWeep Frequency sweep mode ZSPan Zero span mode
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SpanMode)

	def set_mode(self, span_mode: enums.SpanMode) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN:MODE \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.span.set_mode(span_mode = enums.SpanMode.FSWeep) \n
		Selects the measurement mode. \n
			:param span_mode: FSWeep | ZSPan FSWeep Frequency sweep mode ZSPan Zero span mode
		"""
		param = Conversions.enum_scalar_to_str(span_mode, enums.SpanMode)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN:MODE {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.frequency.span.get_value() \n
		Specifies the frequency span for the frequency sweep mode. \n
			:return: frequency_span: Range: 1000 Hz to 2.999901 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN?')
		return Conversions.str_to_float(response)

	def set_value(self, frequency_span: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.span.set_value(frequency_span = 1.0) \n
		Specifies the frequency span for the frequency sweep mode. \n
			:param frequency_span: Range: 1000 Hz to 2.999901 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency_span)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:SPAN {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gslope:
	"""Gslope commands group definition. 15 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gslope", core, parent)

	@property
	def afSettings(self):
		"""afSettings commands group. 3 Sub-classes, 6 commands."""
		if not hasattr(self, '_afSettings'):
			from .Gslope_.AfSettings import AfSettings
			self._afSettings = AfSettings(self._core, self._base)
		return self._afSettings

	@property
	def rfSettings(self):
		"""rfSettings commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_rfSettings'):
			from .Gslope_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	def clone(self) -> 'Gslope':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Gslope(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, control: bool) -> None:
		"""SCPI: SOURce:BASE:ADJustment:STATe \n
		Snippet: driver.source.base.adjustment.state.set(control = False) \n
		Starts or terminates the adjustment of the reference frequency. A query returns the current state. \n
			:param control: ON | OFF ON Starts the adjustment OFF Terminates the adjustment
		"""
		param = Conversions.bool_to_str(control)
		self._core.io.write_with_opc(f'SOURce:BASE:ADJustment:STATe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.GeneratorState:
		"""SCPI: SOURce:BASE:ADJustment:STATe \n
		Snippet: value: enums.GeneratorState = driver.source.base.adjustment.state.get() \n
		Starts or terminates the adjustment of the reference frequency. A query returns the current state. \n
			:return: state: OFF | PENDing | ON OFF No adjustment in progress PENDing State transition ongoing ON Adjustment in progress"""
		response = self._core.io.query_str_with_opc(f'SOURce:BASE:ADJustment:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorState)



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class System:
	"""System commands group definition. 63 total commands, 9 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("system", core, parent)

	@property
	def base(self):
		"""base commands group. 10 Sub-classes, 5 commands."""
		if not hasattr(self, '_base'):
			from .System_.Base import Base
			self._base = Base(self._core, self._base)
		return self._base

	@property
	def deviceFootprint(self):
		"""deviceFootprint commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_deviceFootprint'):
			from .System_.DeviceFootprint import DeviceFootprint
			self._deviceFootprint = DeviceFootprint(self._core, self._base)
		return self._deviceFootprint

	@property
	def display(self):
		"""display commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_display'):
			from .System_.Display import Display
			self._display = Display(self._core, self._base)
		return self._display

	@property
	def error(self):
		"""error commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_error'):
			from .System_.Error import Error
			self._error = Error(self._core, self._base)
		return self._error

	@property
	def help(self):
		"""help commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_help'):
			from .System_.Help import Help
			self._help = Help(self._core, self._base)
		return self._help

	@property
	def update(self):
		"""update commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .System_.Update import Update
			self._update = Update(self._core, self._base)
		return self._update

	@property
	def communicate(self):
		"""communicate commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_communicate'):
			from .System_.Communicate import Communicate
			self._communicate = Communicate(self._core, self._base)
		return self._communicate

	@property
	def option(self):
		"""option commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_option'):
			from .System_.Option import Option
			self._option = Option(self._core, self._base)
		return self._option

	@property
	def password(self):
		"""password commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_password'):
			from .System_.Password import Password
			self._password = Password(self._core, self._base)
		return self._password

	def preset(self) -> None:
		"""SCPI: SYSTem:PRESet \n
		Snippet: driver.system.preset() \n
		Presets or resets a selected application package in all scenarios. If <Application> is omitted, all applications are
		preset or reset. \n
		"""
		self._core.io.write(f'SYSTem:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: SYSTem:PRESet \n
		Snippet: driver.system.preset_with_opc() \n
		Presets or resets a selected application package in all scenarios. If <Application> is omitted, all applications are
		preset or reset. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:PRESet')

	def preset_all(self) -> None:
		"""SCPI: SYSTem:PRESet:ALL \n
		Snippet: driver.system.preset_all() \n
		Presets or resets the base settings and all applications in all scenarios. \n
		"""
		self._core.io.write(f'SYSTem:PRESet:ALL')

	def preset_all_with_opc(self) -> None:
		"""SCPI: SYSTem:PRESet:ALL \n
		Snippet: driver.system.preset_all_with_opc() \n
		Presets or resets the base settings and all applications in all scenarios. \n
		Same as preset_all, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:PRESet:ALL')

	def preset_base(self) -> None:
		"""SCPI: SYSTem:PRESet:BASE \n
		Snippet: driver.system.preset_base() \n
		Presets or resets only the base settings, not the applications. \n
		"""
		self._core.io.write(f'SYSTem:PRESet:BASE')

	def preset_base_with_opc(self) -> None:
		"""SCPI: SYSTem:PRESet:BASE \n
		Snippet: driver.system.preset_base_with_opc() \n
		Presets or resets only the base settings, not the applications. \n
		Same as preset_base, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:PRESet:BASE')

	def reset(self) -> None:
		"""SCPI: SYSTem:RESet \n
		Snippet: driver.system.reset() \n
		Presets or resets a selected application package in all scenarios. If <Application> is omitted, all applications are
		preset or reset. \n
		"""
		self._core.io.write(f'SYSTem:RESet')

	def reset_with_opc(self) -> None:
		"""SCPI: SYSTem:RESet \n
		Snippet: driver.system.reset_with_opc() \n
		Presets or resets a selected application package in all scenarios. If <Application> is omitted, all applications are
		preset or reset. \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:RESet')

	def reset_all(self) -> None:
		"""SCPI: SYSTem:RESet:ALL \n
		Snippet: driver.system.reset_all() \n
		Presets or resets the base settings and all applications in all scenarios. \n
		"""
		self._core.io.write(f'SYSTem:RESet:ALL')

	def reset_all_with_opc(self) -> None:
		"""SCPI: SYSTem:RESet:ALL \n
		Snippet: driver.system.reset_all_with_opc() \n
		Presets or resets the base settings and all applications in all scenarios. \n
		Same as reset_all, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:RESet:ALL')

	def reset_base(self) -> None:
		"""SCPI: SYSTem:RESet:BASE \n
		Snippet: driver.system.reset_base() \n
		Presets or resets only the base settings, not the applications. \n
		"""
		self._core.io.write(f'SYSTem:RESet:BASE')

	def reset_base_with_opc(self) -> None:
		"""SCPI: SYSTem:RESet:BASE \n
		Snippet: driver.system.reset_base_with_opc() \n
		Presets or resets only the base settings, not the applications. \n
		Same as reset_base, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:RESet:BASE')

	def clone(self) -> 'System':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = System(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 3 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("marker", core, parent)
		
		self._base.multi_repcap_types = "Marker,MarkerOther"

	@property
	def absolute(self):
		"""absolute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_absolute'):
			from .Marker_.Absolute import Absolute
			self._absolute = Absolute(self._core, self._base)
		return self._absolute

	@property
	def relative(self):
		"""relative commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_relative'):
			from .Marker_.Relative import Relative
			self._relative = Relative(self._core, self._base)
		return self._relative

	# noinspection PyTypeChecker
	class FetchStruct(StructBase):
		"""Response structure. Fields: \n
			- Xvalue: float: X-value of the marker Unit: Hz
			- Absolute_Yvalue: float: Y-value of the marker Unit: Depends on input path and demodulation type"""
		__meta_args_list = [
			ArgStruct.scalar_float('Xvalue'),
			ArgStruct.scalar_float('Absolute_Yvalue')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Xvalue: float = None
			self.Absolute_Yvalue: float = None

	def fetch(self, trace: enums.Statistic, freq_value: float, channel=repcap.Channel.Default, marker=repcap.Marker.Nr1) -> FetchStruct:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:SIN<nr>:MARKer<mnr> \n
		Snippet: value: FetchStruct = driver.afRf.measurement.multiEval.fft.spdif.marker.fetch(trace = enums.Statistic.AVERage, freq_value = 1.0, channel = repcap.Channel.Default, marker = repcap.Marker.Nr1) \n
		Moves marker number <mnr> to a specified x-value and returns the absolute coordinates. Absolute placement is used. Select
		the trace to be evaluated and the x-value. \n
			:param trace: CURRent | AVERage | MAXimum | MINimum Selects the trace type
			:param freq_value: X-value for which the coordinates are queried Range: 0 Hz to 21 kHz
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Spdif')
			:param marker: optional repeated capability selector. Default value: Nr1
			:return: structure: for return value, see the help for FetchStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('trace', trace, DataType.Enum), ArgSingle('freq_value', freq_value, DataType.Float))
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		marker_cmd_val = self._base.get_repcap_cmd_value(marker, repcap.Marker)
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:SIN{channel_cmd_val}:MARKer{marker_cmd_val}? {param}'.rstrip(), self.__class__.FetchStruct())

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.OutputConnector:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:RFSettings:CONNector \n
		Snippet: value: enums.OutputConnector = driver.source.avionics.generator.rfSettings.get_connector() \n
		Selects the output connector for the generated RF signal. \n
			:return: connector: RFCom | RFOut
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:RFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.OutputConnector)

	def set_connector(self, connector: enums.OutputConnector) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:RFSettings:CONNector \n
		Snippet: driver.source.avionics.generator.rfSettings.set_connector(connector = enums.OutputConnector.RFCom) \n
		Selects the output connector for the generated RF signal. \n
			:param connector: RFCom | RFOut
		"""
		param = Conversions.enum_scalar_to_str(connector, enums.OutputConnector)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:RFSettings:CONNector {param}')

	def get_eattenuation(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:RFSettings:EATTenuation \n
		Snippet: value: float = driver.source.avionics.generator.rfSettings.get_eattenuation() \n
		Specifies the external attenuation in the RF output path. Negative values specify a gain. \n
			:return: ext_atten: Range: -50 dB to 90 dB, Unit: dB
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:RFSettings:EATTenuation?')
		return Conversions.str_to_float(response)

	def set_eattenuation(self, ext_atten: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:RFSettings:EATTenuation \n
		Snippet: driver.source.avionics.generator.rfSettings.set_eattenuation(ext_atten = 1.0) \n
		Specifies the external attenuation in the RF output path. Negative values specify a gain. \n
			:param ext_atten: Range: -50 dB to 90 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(ext_atten)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:RFSettings:EATTenuation {param}')



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sequence:
	"""Sequence commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sequence", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Length: int: Length of the tone sequence (number of digits)
			- Sequence: List[str]: Comma-separated list of 42 strings Each string indicates a dialed digit."""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_int('Length'),
			ArgStruct('Sequence', DataType.StringList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Length: int = None
			self.Sequence: List[str] = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:VOIP:SEQuence \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.tones.voip.sequence.fetch() \n
		Queries the digit results of a tone sequence analysis. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:VOIP:SEQuence?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:TONes:VOIP:SEQuence \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.tones.voip.sequence.read() \n
		Queries the digit results of a tone sequence analysis. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:TONes:VOIP:SEQuence?', self.__class__.ResultData())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demodulation:
	"""Demodulation commands group definition. 16 total commands, 3 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demodulation", core, parent)

	@property
	def fdeviation(self):
		"""fdeviation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Demodulation_.Fdeviation import Fdeviation
			self._fdeviation = Fdeviation(self._core, self._base)
		return self._fdeviation

	@property
	def pdeviation(self):
		"""pdeviation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_pdeviation'):
			from .Demodulation_.Pdeviation import Pdeviation
			self._pdeviation = Pdeviation(self._core, self._base)
		return self._pdeviation

	@property
	def fmStereo(self):
		"""fmStereo commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_fmStereo'):
			from .Demodulation_.FmStereo import FmStereo
			self._fmStereo = FmStereo(self._core, self._base)
		return self._fmStereo

	# noinspection PyTypeChecker
	class ThDistortionStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper THD limit Range: 0.001 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_th_distortion(self) -> ThDistortionStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDistortion \n
		Snippet: value: ThDistortionStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.get_th_distortion() \n
		Configures a limit for the THD results, measured via the RF input path. \n
			:return: structure: for return value, see the help for ThDistortionStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDistortion?', self.__class__.ThDistortionStruct())

	def set_th_distortion(self, value: ThDistortionStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDistortion \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.set_th_distortion(value = ThDistortionStruct()) \n
		Configures a limit for the THD results, measured via the RF input path. \n
			:param value: see the help for ThDistortionStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDistortion', value)

	# noinspection PyTypeChecker
	class ThdNoiseStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper THD+N limit Range: 0.001 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_thd_noise(self) -> ThdNoiseStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDNoise \n
		Snippet: value: ThdNoiseStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.get_thd_noise() \n
		Configures a limit for the THD+N results, measured via the RF input path. \n
			:return: structure: for return value, see the help for ThdNoiseStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDNoise?', self.__class__.ThdNoiseStruct())

	def set_thd_noise(self, value: ThdNoiseStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDNoise \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.set_thd_noise(value = ThdNoiseStruct()) \n
		Configures a limit for the THD+N results, measured via the RF input path. \n
			:param value: see the help for ThdNoiseStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:THDNoise', value)

	# noinspection PyTypeChecker
	class SnRatioStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower limit Range: 1 dB to 46 dB, Unit: dB
			- Upper: float: Upper limit Range: 1 dB to 46 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_sn_ratio(self) -> SnRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNRatio \n
		Snippet: value: SnRatioStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.get_sn_ratio() \n
		Configures limits for all SNR results, measured via the RF input path. SNR results include S/N, (S+N) /N and (S+N+D) /N. \n
			:return: structure: for return value, see the help for SnRatioStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNRatio?', self.__class__.SnRatioStruct())

	def set_sn_ratio(self, value: SnRatioStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.set_sn_ratio(value = SnRatioStruct()) \n
		Configures limits for all SNR results, measured via the RF input path. SNR results include S/N, (S+N) /N and (S+N+D) /N. \n
			:param value: see the help for SnRatioStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNRatio', value)

	# noinspection PyTypeChecker
	class SnnRatioStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: No parameter help available
			- Lower: float: No parameter help available
			- Upper: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_snn_ratio(self) -> SnnRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNNRatio \n
		Snippet: value: SnnRatioStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.get_snn_ratio() \n
		No command help available \n
			:return: structure: for return value, see the help for SnnRatioStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNNRatio?', self.__class__.SnnRatioStruct())

	def set_snn_ratio(self, value: SnnRatioStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNNRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.set_snn_ratio(value = SnnRatioStruct()) \n
		No command help available \n
			:param value: see the help for SnnRatioStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNNRatio', value)

	# noinspection PyTypeChecker
	class SinadStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower SINAD limit Range: 0 dB to 140 dB, Unit: dB
			- Upper: float: Upper SINAD limit Range: 0 dB to 140 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_sinad(self) -> SinadStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SINad \n
		Snippet: value: SinadStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.get_sinad() \n
		Configures limits for the SINAD results, measured via the RF input path. \n
			:return: structure: for return value, see the help for SinadStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SINad?', self.__class__.SinadStruct())

	def set_sinad(self, value: SinadStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SINad \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.set_sinad(value = SinadStruct()) \n
		Configures limits for the SINAD results, measured via the RF input path. \n
			:param value: see the help for SinadStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SINad', value)

	# noinspection PyTypeChecker
	class SndRatioStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: No parameter help available
			- Lower: float: No parameter help available
			- Upper: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_snd_ratio(self) -> SndRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNDRatio \n
		Snippet: value: SndRatioStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.get_snd_ratio() \n
		No command help available \n
			:return: structure: for return value, see the help for SndRatioStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNDRatio?', self.__class__.SndRatioStruct())

	def set_snd_ratio(self, value: SndRatioStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNDRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.set_snd_ratio(value = SndRatioStruct()) \n
		No command help available \n
			:param value: see the help for SndRatioStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:SNDRatio', value)

	def clone(self) -> 'Demodulation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Demodulation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Average:
	"""Average commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("average", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Freq: List[float]: Tone frequency Unit: Hz
			- Level: List[float]: Audio level measured at the tone frequency Unit: dBV"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct('Freq', DataType.FloatList, None, False, True, 1),
			ArgStruct('Level', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Freq: List[float] = None
			self.Level: List[float] = None

	def fetch(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:MTONes:AIN<Nr>:AVERage \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.mtones.audioInput.average.fetch(audioInput = repcap.AudioInput.Default) \n
		Queries the multitone results measured for an AF input path. The results are returned in the following order:
		<Reliability>, {<Freq>, <Level>}Tone 1, ..., {<Freq>, <Level>}Tone 20 \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:MTONes:AIN{audioInput_cmd_val}:AVERage?', self.__class__.ResultData())

	def read(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:MTONes:AIN<Nr>:AVERage \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.mtones.audioInput.average.read(audioInput = repcap.AudioInput.Default) \n
		Queries the multitone results measured for an AF input path. The results are returned in the following order:
		<Reliability>, {<Freq>, <Level>}Tone 1, ..., {<Freq>, <Level>}Tone 20 \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:MTONes:AIN{audioInput_cmd_val}:AVERage?', self.__class__.ResultData())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 1 Sub-groups, 1 group commands
	Repeated Capability: FrequencyLobe, default value after init: FrequencyLobe.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_frequencyLobe_get', 'repcap_frequencyLobe_set', repcap.FrequencyLobe.Nr1)

	def repcap_frequencyLobe_set(self, enum_value: repcap.FrequencyLobe) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FrequencyLobe.Default
		Default value after init: FrequencyLobe.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_frequencyLobe_get(self) -> repcap.FrequencyLobe:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Frequency_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	def set(self, freq_1: int, frequencyLobe=repcap.FrequencyLobe.Default) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency<nr> \n
		Snippet: driver.source.avionics.generator.ils.localizer.afSettings.frequency.set(freq_1 = 1, frequencyLobe = repcap.FrequencyLobe.Default) \n
		Configures the audio frequency for one lobe. \n
			:param freq_1: Range and reset value depend on no Range: 72 Hz to 108 Hz / 120 Hz to 180 Hz , Unit: Hz
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frequency')"""
		param = Conversions.decimal_value_to_str(freq_1)
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency{frequencyLobe_cmd_val} {param}')

	def get(self, frequencyLobe=repcap.FrequencyLobe.Default) -> int:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency<nr> \n
		Snippet: value: int = driver.source.avionics.generator.ils.localizer.afSettings.frequency.get(frequencyLobe = repcap.FrequencyLobe.Default) \n
		Configures the audio frequency for one lobe. \n
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frequency')
			:return: freq_1: Range and reset value depend on no Range: 72 Hz to 108 Hz / 120 Hz to 180 Hz , Unit: Hz"""
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		response = self._core.io.query_str(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency{frequencyLobe_cmd_val}?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tmode:
	"""Tmode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tmode", core, parent)

	def set(self, tone_mode: enums.ToneMode, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:TMODe \n
		Snippet: driver.configure.afRf.measurement.audioInput.tmode.set(tone_mode = enums.ToneMode.NOISe, audioInput = repcap.AudioInput.Default) \n
		No command help available \n
			:param tone_mode: No help available
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(tone_mode, enums.ToneMode)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:TMODe {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.ToneMode:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:TMODe \n
		Snippet: value: enums.ToneMode = driver.configure.afRf.measurement.audioInput.tmode.get(audioInput = repcap.AudioInput.Default) \n
		No command help available \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: tone_mode: No help available"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:TMODe?')
		return Conversions.str_to_scalar_enum(response, enums.ToneMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Source:
	"""Source commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("source", core, parent)

	# noinspection PyTypeChecker
	def get(self, audioOutput=repcap.AudioOutput.Default) -> enums.AudioSource:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AOUT<nr>:SOURce \n
		Snippet: value: enums.AudioSource = driver.configure.afRf.measurement.audioOutput.source.get(audioOutput = repcap.AudioOutput.Default) \n
		Queries the audio signal source for an AF OUT connector. \n
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')
			:return: source: DEM | DEML | DEMR DEM Demodulator output (FM, PM, ...) DEML Demodulator output, left channel (FM stereo) DEMR Demodulator output, right channel (FM stereo)"""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AOUT{audioOutput_cmd_val}:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.AudioSource)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Size:
	"""Size commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("size", core, parent)

	def set(self, ifile_size: int, instrument=repcap.Instrument.Default) -> None:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:SIZE \n
		Snippet: driver.trace.remote.mode.file.size.set(ifile_size = 1, instrument = repcap.Instrument.Default) \n
		Specifies the maximum trace file size in bytes. \n
			:param ifile_size: Recommended minimum value: 40000 bytes Maximum value: 1000000000 bytes (1 GB) Default value: 1000000000 bytes (1 GB)
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')"""
		param = Conversions.decimal_value_to_str(ifile_size)
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		self._core.io.write(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:SIZE {param}')

	def get(self, instrument=repcap.Instrument.Default) -> int:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:SIZE \n
		Snippet: value: int = driver.trace.remote.mode.file.size.get(instrument = repcap.Instrument.Default) \n
		Specifies the maximum trace file size in bytes. \n
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
			:return: ifile_size: No help available"""
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		response = self._core.io.query_str(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:SIZE?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.Utilities import trim_str_response
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPy:
	"""ListPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("listPy", core, parent)

	def get(self, product_type: enums.OptionsProductType = None, validity: enums.OptionValidity = None, scope: enums.OptionsScope = None, instrument_no: float = None) -> str:
		"""SCPI: SYSTem:BASE:OPTion:LIST \n
		Snippet: value: str = driver.system.base.option.listPy.get(product_type = enums.OptionsProductType.ALL, validity = enums.OptionValidity.ALL, scope = enums.OptionsScope.INSTrument, instrument_no = 1.0) \n
		Returns a list of installed software options (licenses) , hardware options, software packages and applications. The list
		can be filtered via parameters. If filtering results in an empty list, a '0' is returned. \n
			:param product_type: No help available
			:param validity: FUNCtional | VALid | ALL FUNCtional List only functional hardware options or applications. HWOPtion: Is functional if the hardware option and all its components can be used (no defect detected) . FWA: Is functional if the required hardware, software and license keys are available and functional. VALid List only valid software options. SWOPtion: Is valid if an active license key is available. ALL Disable filtering (default if parameter is omitted) .
			:param scope: No help available
			:param instrument_no: No help available
			:return: option_list: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('product_type', product_type, DataType.Enum, True), ArgSingle('validity', validity, DataType.Enum, True), ArgSingle('scope', scope, DataType.Enum, True), ArgSingle('instrument_no', instrument_no, DataType.Float, True))
		response = self._core.io.query_str(f'SYSTem:BASE:OPTion:LIST? {param}'.rstrip())
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 8 total commands, 2 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	@property
	def span(self):
		"""span commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_span'):
			from .Frequency_.Span import Span
			self._span = Span(self._core, self._base)
		return self._span

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .Frequency_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	def get_center(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:CENTer \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.frequency.get_center() \n
		Specifies the center frequency of the measurement. You can also configure this setting via method RsCma.Configure.
		GprfMeasurement.RfSettings.frequency. \n
			:return: center_frequency: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:CENTer?')
		return Conversions.str_to_float(response)

	def set_center(self, center_frequency: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:CENTer \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.set_center(center_frequency = 1.0) \n
		Specifies the center frequency of the measurement. You can also configure this setting via method RsCma.Configure.
		GprfMeasurement.RfSettings.frequency. \n
			:param center_frequency: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(center_frequency)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:CENTer {param}')

	def get_start(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STARt \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.frequency.get_start() \n
		Specifies the start frequency of the measured span for the frequency sweep mode. \n
			:return: start_frequency: Range: 99500 Hz to 2.9999995 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STARt?')
		return Conversions.str_to_float(response)

	def set_start(self, start_frequency: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STARt \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.set_start(start_frequency = 1.0) \n
		Specifies the start frequency of the measured span for the frequency sweep mode. \n
			:param start_frequency: Range: 99500 Hz to 2.9999995 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(start_frequency)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STARt {param}')

	def get_stop(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STOP \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.frequency.get_stop() \n
		Specifies the stop frequency of the measured span for the frequency sweep mode. \n
			:return: stop_frequency: Range: 100500 Hz to 3.0000005 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STOP?')
		return Conversions.str_to_float(response)

	def set_stop(self, stop_frequency: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STOP \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.set_stop(stop_frequency = 1.0) \n
		Specifies the stop frequency of the measured span for the frequency sweep mode. \n
			:param stop_frequency: Range: 100500 Hz to 3.0000005 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(stop_frequency)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:STOP {param}')

	def get_laspan(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:LASPan \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.frequency.get_laspan() \n
		No command help available \n
			:return: last_span: No help available
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:LASPan?')
		return Conversions.str_to_float(response)

	def set_laspan(self, last_span: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:LASPan \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.set_laspan(last_span = 1.0) \n
		No command help available \n
			:param last_span: No help available
		"""
		param = Conversions.decimal_value_to_str(last_span)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:LASPan {param}')

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Adjustment:
	"""Adjustment commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("adjustment", core, parent)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.OscillatorType:
		"""SCPI: CONFigure:BASE:ADJustment:TYPE \n
		Snippet: value: enums.OscillatorType = driver.configure.base.adjustment.get_type_py() \n
		Selects the frequency source to be adjusted. \n
			:return: adj_type: TCXO | OCXO
		"""
		response = self._core.io.query_str('CONFigure:BASE:ADJustment:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.OscillatorType)

	def set_type_py(self, adj_type: enums.OscillatorType) -> None:
		"""SCPI: CONFigure:BASE:ADJustment:TYPE \n
		Snippet: driver.configure.base.adjustment.set_type_py(adj_type = enums.OscillatorType.OCXO) \n
		Selects the frequency source to be adjusted. \n
			:param adj_type: TCXO | OCXO
		"""
		param = Conversions.enum_scalar_to_str(adj_type, enums.OscillatorType)
		self._core.io.write(f'CONFigure:BASE:ADJustment:TYPE {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:BASE:ADJustment:VALue \n
		Snippet: value: float = driver.configure.base.adjustment.get_value() \n
		Adjusts the reference frequency. A lower value decreases the frequency. A higher value increases it. \n
			:return: adj_value: Range: 0 to 65535
		"""
		response = self._core.io.query_str('CONFigure:BASE:ADJustment:VALue?')
		return Conversions.str_to_float(response)

	def set_value(self, adj_value: float) -> None:
		"""SCPI: CONFigure:BASE:ADJustment:VALue \n
		Snippet: driver.configure.base.adjustment.set_value(adj_value = 1.0) \n
		Adjusts the reference frequency. A lower value decreases the frequency. A higher value increases it. \n
			:param adj_value: Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(adj_value)
		self._core.io.write(f'CONFigure:BASE:ADJustment:VALue {param}')

	def save(self) -> None:
		"""SCPI: CONFigure:BASE:ADJustment:SAVE \n
		Snippet: driver.configure.base.adjustment.save() \n
		Stores the configured adjustment value. \n
		"""
		self._core.io.write(f'CONFigure:BASE:ADJustment:SAVE')

	def save_with_opc(self) -> None:
		"""SCPI: CONFigure:BASE:ADJustment:SAVE \n
		Snippet: driver.configure.base.adjustment.save_with_opc() \n
		Stores the configured adjustment value. \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'CONFigure:BASE:ADJustment:SAVE')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Merror:
	"""Merror commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("merror", core, parent)

	# noinspection PyTypeChecker
	class RmsStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Limit: float: Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Limit')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Limit: float = None

	def get_rms(self) -> RmsStruct:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:RMS \n
		Snippet: value: RmsStruct = driver.configure.vse.measurement.limit.dmr.merror.get_rms() \n
		Configures an upper limit for the measured RMS value of the magnitude error. \n
			:return: structure: for return value, see the help for RmsStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:RMS?', self.__class__.RmsStruct())

	def set_rms(self, value: RmsStruct) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:RMS \n
		Snippet: driver.configure.vse.measurement.limit.dmr.merror.set_rms(value = RmsStruct()) \n
		Configures an upper limit for the measured RMS value of the magnitude error. \n
			:param value: see the help for RmsStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:RMS', value)

	# noinspection PyTypeChecker
	class PeakStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Limit: float: Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Limit')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Limit: float = None

	def get_peak(self) -> PeakStruct:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:PEAK \n
		Snippet: value: PeakStruct = driver.configure.vse.measurement.limit.dmr.merror.get_peak() \n
		Configures an upper limit for the measured peak value of the magnitude error. \n
			:return: structure: for return value, see the help for PeakStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:PEAK?', self.__class__.PeakStruct())

	def set_peak(self, value: PeakStruct) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:PEAK \n
		Snippet: driver.configure.vse.measurement.limit.dmr.merror.set_peak(value = PeakStruct()) \n
		Configures an upper limit for the measured peak value of the magnitude error. \n
			:param value: see the help for PeakStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:VSE:MEASurement<Instance>:LIMit:DMR:MERRor:PEAK', value)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AfSettings:
	"""AfSettings commands group definition. 11 total commands, 3 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("afSettings", core, parent)

	@property
	def audioOutput(self):
		"""audioOutput commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_audioOutput'):
			from .AfSettings_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .AfSettings_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def fmoddepth(self):
		"""fmoddepth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmoddepth'):
			from .AfSettings_.Fmoddepth import Fmoddepth
			self._fmoddepth = Fmoddepth(self._core, self._base)
		return self._fmoddepth

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.AudioConnector:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:CONNector \n
		Snippet: value: enums.AudioConnector = driver.source.avionics.generator.ils.gslope.afSettings.get_connector() \n
		Selects the output connector for the generated AF signal (AF1 OUT or AF2 OUT) . If you want to route both the localizer
		signal and the glide slope signal to an AF output, you must configure different connectors for the two signals. \n
			:return: connector: AF1O | AF2O
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.AudioConnector)

	def set_connector(self, connector: enums.AudioConnector) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:CONNector \n
		Snippet: driver.source.avionics.generator.ils.gslope.afSettings.set_connector(connector = enums.AudioConnector.AF1O) \n
		Selects the output connector for the generated AF signal (AF1 OUT or AF2 OUT) . If you want to route both the localizer
		signal and the glide slope signal to an AF output, you must configure different connectors for the two signals. \n
			:param connector: AF1O | AF2O
		"""
		param = Conversions.enum_scalar_to_str(connector, enums.AudioConnector)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:CONNector {param}')

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.ils.gslope.afSettings.get_enable() \n
		Enables or disables the modulation of the RF carrier with the audio tones for the two lobes. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:ENABle \n
		Snippet: driver.source.avionics.generator.ils.gslope.afSettings.set_enable(enable = False) \n
		Enables or disables the modulation of the RF carrier with the audio tones for the two lobes. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:ENABle {param}')

	def get_sdm(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:SDM \n
		Snippet: value: float = driver.source.avionics.generator.ils.gslope.afSettings.get_sdm() \n
		Sets the sum of depth of modulations (SDM) . \n
			:return: mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:SDM?')
		return Conversions.str_to_float(response)

	def set_sdm(self, mod_depth: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:SDM \n
		Snippet: driver.source.avionics.generator.ils.gslope.afSettings.set_sdm(mod_depth = 1.0) \n
		Sets the sum of depth of modulations (SDM) . \n
			:param mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(mod_depth)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:SDM {param}')

	def get_ddm(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:DDM \n
		Snippet: value: float = driver.source.avionics.generator.ils.gslope.afSettings.get_ddm() \n
		Sets the difference in modulation depth between the two lobes. The maximum allowed absolute value is limited by the
		configured SDM value. \n
			:return: ddm: Range: -100 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:DDM?')
		return Conversions.str_to_float(response)

	def set_ddm(self, ddm: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:DDM \n
		Snippet: driver.source.avionics.generator.ils.gslope.afSettings.set_ddm(ddm = 1.0) \n
		Sets the difference in modulation depth between the two lobes. The maximum allowed absolute value is limited by the
		configured SDM value. \n
			:param ddm: Range: -100 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(ddm)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:DDM {param}')

	# noinspection PyTypeChecker
	def get_fly(self) -> enums.UpDownDirection:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:FLY \n
		Snippet: value: enums.UpDownDirection = driver.source.avionics.generator.ils.gslope.afSettings.get_fly() \n
		Sets the direction towards the ideal line (fly up or fly down) and the sign of the configured DDM value. \n
			:return: direction: UP | DOWN
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:FLY?')
		return Conversions.str_to_scalar_enum(response, enums.UpDownDirection)

	def set_fly(self, direction: enums.UpDownDirection) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:FLY \n
		Snippet: driver.source.avionics.generator.ils.gslope.afSettings.set_fly(direction = enums.UpDownDirection.DOWN) \n
		Sets the direction towards the ideal line (fly up or fly down) and the sign of the configured DDM value. \n
			:param direction: UP | DOWN
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.UpDownDirection)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:FLY {param}')

	def get_poffset(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:POFFset \n
		Snippet: value: float = driver.source.avionics.generator.ils.gslope.afSettings.get_poffset() \n
		Sets the phase offset between the audio signals of the two lobes. \n
			:return: poffset: Range: -60 deg to 120 deg, Unit: deg
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:POFFset?')
		return Conversions.str_to_float(response)

	def set_poffset(self, poffset: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:POFFset \n
		Snippet: driver.source.avionics.generator.ils.gslope.afSettings.set_poffset(poffset = 1.0) \n
		Sets the phase offset between the audio signals of the two lobes. \n
			:param poffset: Range: -60 deg to 120 deg, Unit: deg
		"""
		param = Conversions.decimal_value_to_str(poffset)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:AFSettings:POFFset {param}')

	def clone(self) -> 'AfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ........Internal.Types import DataType
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	def fetch(self, audioInput=repcap.AudioInput.Default) -> List[float]:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:AIN<Nr>:POWer:CURRent \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.fft.audioInput.power.current.fetch(audioInput = repcap.AudioInput.Default) \n
		Queries the contents of the spectrum diagram for an AF input path. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: power: Comma-separated list of 1793 audio level values (diagram from left to right) Unit: dBV"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:AIN{audioInput_cmd_val}:POWer:CURRent?', suppressed)
		return response

	def read(self, audioInput=repcap.AudioInput.Default) -> List[float]:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:FFT:AIN<Nr>:POWer:CURRent \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.fft.audioInput.power.current.read(audioInput = repcap.AudioInput.Default) \n
		Queries the contents of the spectrum diagram for an AF input path. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: power: Comma-separated list of 1793 audio level values (diagram from left to right) Unit: dBV"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:AFRF:MEASurement<Instance>:MEValuation:FFT:AIN{audioInput_cmd_val}:POWer:CURRent?', suppressed)
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reference:
	"""Reference commands group definition. 6 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reference", core, parent)

	@property
	def fdeviation(self):
		"""fdeviation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Reference_.Fdeviation import Fdeviation
			self._fdeviation = Fdeviation(self._core, self._base)
		return self._fdeviation

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.vor.afSettings.reference.get_enable() \n
		Enables or disables the REF signal. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:ENABle \n
		Snippet: driver.source.avionics.generator.vor.afSettings.reference.set_enable(enable = False) \n
		Enables or disables the REF signal. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:ENABle {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:MDEPth \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.reference.get_mod_depth() \n
		Sets the AM modulation depth of the FM subcarrier. The sum of the modulation depths for all enabled components must not
		exceed 100 %. \n
			:return: vor_mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, vor_mod_depth: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:MDEPth \n
		Snippet: driver.source.avionics.generator.vor.afSettings.reference.set_mod_depth(vor_mod_depth = 1.0) \n
		Sets the AM modulation depth of the FM subcarrier. The sum of the modulation depths for all enabled components must not
		exceed 100 %. \n
			:param vor_mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(vor_mod_depth)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:MDEPth {param}')

	def get_cfrequency(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:CFRequency \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.reference.get_cfrequency() \n
		Sets the center frequency of the FM subcarrier. \n
			:return: freq: Range: 7500 Hz to 12.5 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:CFRequency?')
		return Conversions.str_to_float(response)

	def set_cfrequency(self, freq: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:CFRequency \n
		Snippet: driver.source.avionics.generator.vor.afSettings.reference.set_cfrequency(freq = 1.0) \n
		Sets the center frequency of the FM subcarrier. \n
			:param freq: Range: 7500 Hz to 12.5 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:CFRequency {param}')

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FREQuency \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.reference.get_frequency() \n
		Sets the audio frequency of the REF signal and the VAR signal. \n
			:return: freq: Range: 20 Hz to 40 Hz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, freq: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FREQuency \n
		Snippet: driver.source.avionics.generator.vor.afSettings.reference.set_frequency(freq = 1.0) \n
		Sets the audio frequency of the REF signal and the VAR signal. \n
			:param freq: Range: 20 Hz to 40 Hz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FREQuency {param}')

	def clone(self) -> 'Reference':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Reference(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ccode:
	"""Ccode commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ccode", core, parent)

	def get_calculation(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:CCODe:CALCulation \n
		Snippet: value: bool = driver.source.afRf.generator.dpmr.ccode.get_calculation() \n
		No command help available \n
			:return: calculation: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:CCODe:CALCulation?')
		return Conversions.str_to_bool(response)

	def set_calculation(self, calculation: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:CCODe:CALCulation \n
		Snippet: driver.source.afRf.generator.dpmr.ccode.set_calculation(calculation = False) \n
		No command help available \n
			:param calculation: No help available
		"""
		param = Conversions.bool_to_str(calculation)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:CCODe:CALCulation {param}')

	def get_value(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:CCODe \n
		Snippet: value: int = driver.source.afRf.generator.dpmr.ccode.get_value() \n
		No command help available \n
			:return: ccode: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DPMR:CCODe?')
		return Conversions.str_to_int(response)

	def set_value(self, ccode: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DPMR:CCODe \n
		Snippet: driver.source.afRf.generator.dpmr.ccode.set_value(ccode = 1) \n
		No command help available \n
			:param ccode: No help available
		"""
		param = Conversions.decimal_value_to_str(ccode)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DPMR:CCODe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limit:
	"""Limit commands group definition. 26 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("limit", core, parent)

	@property
	def dmr(self):
		"""dmr commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_dmr'):
			from .Limit_.Dmr import Dmr
			self._dmr = Dmr(self._core, self._base)
		return self._dmr

	@property
	def dpmr(self):
		"""dpmr commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpmr'):
			from .Limit_.Dpmr import Dpmr
			self._dpmr = Dpmr(self._core, self._base)
		return self._dpmr

	@property
	def nxdn(self):
		"""nxdn commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_nxdn'):
			from .Limit_.Nxdn import Nxdn
			self._nxdn = Nxdn(self._core, self._base)
		return self._nxdn

	@property
	def tetra(self):
		"""tetra commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tetra'):
			from .Limit_.Tetra import Tetra
			self._tetra = Tetra(self._core, self._base)
		return self._tetra

	@property
	def ptFive(self):
		"""ptFive commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_ptFive'):
			from .Limit_.PtFive import PtFive
			self._ptFive = PtFive(self._core, self._base)
		return self._ptFive

	@property
	def rfCarrier(self):
		"""rfCarrier commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rfCarrier'):
			from .Limit_.RfCarrier import RfCarrier
			self._rfCarrier = RfCarrier(self._core, self._base)
		return self._rfCarrier

	def clone(self) -> 'Limit':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Limit(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tsensitivity:
	"""Tsensitivity commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tsensitivity", core, parent)

	def get_trelative(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TRELative \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tsensitivity.get_trelative() \n
		No command help available \n
			:return: target_relative: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TRELative?')
		return Conversions.str_to_float(response)

	def set_trelative(self, target_relative: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TRELative \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tsensitivity.set_trelative(target_relative = 1.0) \n
		No command help available \n
			:param target_relative: No help available
		"""
		param = Conversions.decimal_value_to_str(target_relative)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TRELative {param}')

	def get_tf_deviation(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TFDeviation \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tsensitivity.get_tf_deviation() \n
		No command help available \n
			:return: target_freq_dev: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TFDeviation?')
		return Conversions.str_to_float(response)

	def set_tf_deviation(self, target_freq_dev: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TFDeviation \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tsensitivity.set_tf_deviation(target_freq_dev = 1.0) \n
		No command help available \n
			:param target_freq_dev: No help available
		"""
		param = Conversions.decimal_value_to_str(target_freq_dev)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TFDeviation {param}')

	def get_tp_deviation(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TPDeviation \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tsensitivity.get_tp_deviation() \n
		No command help available \n
			:return: target_phase_dev: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TPDeviation?')
		return Conversions.str_to_float(response)

	def set_tp_deviation(self, target_phase_dev: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TPDeviation \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tsensitivity.set_tp_deviation(target_phase_dev = 1.0) \n
		No command help available \n
			:param target_phase_dev: No help available
		"""
		param = Conversions.decimal_value_to_str(target_phase_dev)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TPDeviation {param}')

	def get_tm_depth(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TMDepth \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tsensitivity.get_tm_depth() \n
		No command help available \n
			:return: target_mod_depth: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TMDepth?')
		return Conversions.str_to_float(response)

	def set_tm_depth(self, target_mod_depth: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TMDepth \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tsensitivity.set_tm_depth(target_mod_depth = 1.0) \n
		No command help available \n
			:param target_mod_depth: No help available
		"""
		param = Conversions.decimal_value_to_str(target_mod_depth)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TMDepth {param}')

	def get_ttolerance(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TTOLerance \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.tsensitivity.get_ttolerance() \n
		No command help available \n
			:return: tolerance: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TTOLerance?')
		return Conversions.str_to_float(response)

	def set_ttolerance(self, tolerance: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TTOLerance \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tsensitivity.set_ttolerance(tolerance = 1.0) \n
		No command help available \n
			:param tolerance: No help available
		"""
		param = Conversions.decimal_value_to_str(tolerance)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TSENsitivity:TTOLerance {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fsk:
	"""Fsk commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fsk", core, parent)

	# noinspection PyTypeChecker
	class BreateStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Limit: bool: OFF | ON Range: 0 to 100
			- Lower: int: Range: 0 to 100
			- Upper: int: Range: -130 dBm to 55 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Limit'),
			ArgStruct.scalar_int('Lower'),
			ArgStruct.scalar_int('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Limit: bool = None
			self.Lower: int = None
			self.Upper: int = None

	def get_breate(self) -> BreateStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:LIMit:FSK:BREate \n
		Snippet: value: BreateStruct = driver.configure.afRf.measurement.data.limit.fsk.get_breate() \n
		Enables a limit check and sets the upper limit for the bit error rate. \n
			:return: structure: for return value, see the help for BreateStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DATA:LIMit:FSK:BREate?', self.__class__.BreateStruct())

	def set_breate(self, value: BreateStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:LIMit:FSK:BREate \n
		Snippet: driver.configure.afRf.measurement.data.limit.fsk.set_breate(value = BreateStruct()) \n
		Enables a limit check and sets the upper limit for the bit error rate. \n
			:param value: see the help for BreateStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DATA:LIMit:FSK:BREate', value)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, tone_type: enums.DialingMode, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DIALing:MODE \n
		Snippet: driver.source.afRf.generator.internalGenerator.dialing.mode.set(tone_type = enums.DialingMode.DTMF, internalGen = repcap.InternalGen.Default) \n
		Selects the dialing mode of an internal audio generator. This command is only relevant for non-dialing tone modes, for
		example tone mode 'single tone' plus dialing mode 'DTMF'. \n
			:param tone_type: DTMF | SELCall | FDIaling | SCAL DTMF DTMF sequence SELCall SelCall selective calling FDIaling Free dialing SCAL SELCAL selective calling
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.enum_scalar_to_str(tone_type, enums.DialingMode)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DIALing:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, internalGen=repcap.InternalGen.Default) -> enums.DialingMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DIALing:MODE \n
		Snippet: value: enums.DialingMode = driver.source.afRf.generator.internalGenerator.dialing.mode.get(internalGen = repcap.InternalGen.Default) \n
		Selects the dialing mode of an internal audio generator. This command is only relevant for non-dialing tone modes, for
		example tone mode 'single tone' plus dialing mode 'DTMF'. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: tone_type: DTMF | SELCall | FDIaling | SCAL DTMF DTMF sequence SELCall SelCall selective calling FDIaling Free dialing SCAL SELCAL selective calling"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DIALing:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.DialingMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 11 total commands, 2 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	@property
	def rf(self):
		"""rf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rf'):
			from .RfSettings_.Rf import Rf
			self._rf = Rf(self._core, self._base)
		return self._rf

	@property
	def farFrequency(self):
		"""farFrequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_farFrequency'):
			from .RfSettings_.FarFrequency import FarFrequency
			self._farFrequency = FarFrequency(self._core, self._base)
		return self._farFrequency

	def get_dgain(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:DGAin \n
		Snippet: value: float = driver.source.afRf.generator.rfSettings.get_dgain() \n
		Specifies a digital gain and thus modifies the configured RMS base level by a specific value. \n
			:return: dig_gain: Range: -30 dB to 0 dB, Unit: dB
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:DGAin?')
		return Conversions.str_to_float(response)

	def set_dgain(self, dig_gain: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:DGAin \n
		Snippet: driver.source.afRf.generator.rfSettings.set_dgain(dig_gain = 1.0) \n
		Specifies a digital gain and thus modifies the configured RMS base level by a specific value. \n
			:param dig_gain: Range: -30 dB to 0 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(dig_gain)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:DGAin {param}')

	def get_eattenuation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:EATTenuation \n
		Snippet: value: float = driver.source.afRf.generator.rfSettings.get_eattenuation() \n
		Specifies the external attenuation in the RF output path. Negative values specify a gain. \n
			:return: rf_output_ext_att: Range: -50 dB to 90 dB, Unit: dB
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:EATTenuation?')
		return Conversions.str_to_float(response)

	def set_eattenuation(self, rf_output_ext_att: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:EATTenuation \n
		Snippet: driver.source.afRf.generator.rfSettings.set_eattenuation(rf_output_ext_att = 1.0) \n
		Specifies the external attenuation in the RF output path. Negative values specify a gain. \n
			:param rf_output_ext_att: Range: -50 dB to 90 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(rf_output_ext_att)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:EATTenuation {param}')

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:FREQuency \n
		Snippet: value: float = driver.source.afRf.generator.rfSettings.get_frequency() \n
		Specifies the center frequency of the unmodulated RF carrier. \n
			:return: frequency: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:FREQuency \n
		Snippet: driver.source.afRf.generator.rfSettings.set_frequency(frequency = 1.0) \n
		Specifies the center frequency of the unmodulated RF carrier. \n
			:param frequency: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:FREQuency {param}')

	def get_level(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:LEVel \n
		Snippet: value: float = driver.source.afRf.generator.rfSettings.get_level() \n
		Specifies the RMS level of the unmodulated RF signal. The allowed range depends on several other settings, for example on
		the selected connector, the frequency and the external attenuation. For supported output level ranges, refer to the data
		sheet. \n
			:return: level: Unit: dBm
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:LEVel \n
		Snippet: driver.source.afRf.generator.rfSettings.set_level(level = 1.0) \n
		Specifies the RMS level of the unmodulated RF signal. The allowed range depends on several other settings, for example on
		the selected connector, the frequency and the external attenuation. For supported output level ranges, refer to the data
		sheet. \n
			:param level: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:LEVel {param}')

	def get_pe_power(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:PEPower \n
		Snippet: value: float = driver.source.afRf.generator.rfSettings.get_pe_power() \n
		Queries the peak envelope power (PEP) . \n
			:return: peak_envelope_power: Unit: dBm
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:PEPower?')
		return Conversions.str_to_float(response)

	def get_rf_coupling(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:RFCoupling \n
		Snippet: value: bool = driver.source.afRf.generator.rfSettings.get_rf_coupling() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:RFCoupling?')
		return Conversions.str_to_bool(response)

	def set_rf_coupling(self, enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:RFCoupling \n
		Snippet: driver.source.afRf.generator.rfSettings.set_rf_coupling(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:RFCoupling {param}')

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.OutputConnector:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:CONNector \n
		Snippet: value: enums.OutputConnector = driver.source.afRf.generator.rfSettings.get_connector() \n
		Selects the output connector for the generated RF signal. \n
			:return: output_connector: RFCom | RFOut
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.OutputConnector)

	def set_connector(self, output_connector: enums.OutputConnector) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:CONNector \n
		Snippet: driver.source.afRf.generator.rfSettings.set_connector(output_connector = enums.OutputConnector.RFCom) \n
		Selects the output connector for the generated RF signal. \n
			:param output_connector: RFCom | RFOut
		"""
		param = Conversions.enum_scalar_to_str(output_connector, enums.OutputConnector)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:CONNector {param}')

	def get_channel(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:CHANnel \n
		Snippet: value: int = driver.source.afRf.generator.rfSettings.get_channel() \n
		Specifies the center frequency of the unmodulated RF carrier via a channel number, according to the configured channel
		definition. \n
			:return: channel: Range: 0 Ch to 9999 Ch, Unit: Ch
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:CHANnel?')
		return Conversions.str_to_int(response)

	def set_channel(self, channel: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:CHANnel \n
		Snippet: driver.source.afRf.generator.rfSettings.set_channel(channel = 1) \n
		Specifies the center frequency of the unmodulated RF carrier via a channel number, according to the configured channel
		definition. \n
			:param channel: Range: 0 Ch to 9999 Ch, Unit: Ch
		"""
		param = Conversions.decimal_value_to_str(channel)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:CHANnel {param}')

	def get_coffset(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:COFFset \n
		Snippet: value: float = driver.source.afRf.generator.rfSettings.get_coffset() \n
		Shifts the center frequency of the unmodulated RF carrier by a channel offset, relative to the frequency defined via the
		channel number. The range depends on the channel spacing, defined via method RsCma.Source.AfRf.Generator.Cdefinition.
		cspace. \n
			:return: channel_offset: Range: -Spacing/2 Hz to +Spacing/2 Hz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:RFSettings:COFFset?')
		return Conversions.str_to_float(response)

	def set_coffset(self, channel_offset: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:COFFset \n
		Snippet: driver.source.afRf.generator.rfSettings.set_coffset(channel_offset = 1.0) \n
		Shifts the center frequency of the unmodulated RF carrier by a channel offset, relative to the frequency defined via the
		channel number. The range depends on the channel spacing, defined via method RsCma.Source.AfRf.Generator.Cdefinition.
		cspace. \n
			:param channel_offset: Range: -Spacing/2 Hz to +Spacing/2 Hz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(channel_offset)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:COFFset {param}')

	def clone(self) -> 'RfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPy:
	"""FormatPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("formatPy", core, parent)

	def set(self, eformat: enums.Eformat, instrument=repcap.Instrument.Default) -> None:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:FORMat \n
		Snippet: driver.trace.remote.mode.file.formatPy.set(eformat = enums.Eformat.ASCii, instrument = repcap.Instrument.Default) \n
		Specifies the target file format for tracing of the remote control interface. The trace can be stored as ASCII file or as
		XML file. \n
			:param eformat: ASCii | XML Default value: XML
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')"""
		param = Conversions.enum_scalar_to_str(eformat, enums.Eformat)
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		self._core.io.write(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, instrument=repcap.Instrument.Default) -> enums.Eformat:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:FORMat \n
		Snippet: value: enums.Eformat = driver.trace.remote.mode.file.formatPy.get(instrument = repcap.Instrument.Default) \n
		Specifies the target file format for tracing of the remote control interface. The trace can be stored as ASCII file or as
		XML file. \n
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
			:return: eformat: No help available"""
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		response = self._core.io.query_str(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.Eformat)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 8 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	@property
	def display(self):
		"""display commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_display'):
			from .Mode_.Display import Display
			self._display = Display(self._core, self._base)
		return self._display

	@property
	def file(self):
		"""file commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .Mode_.File import File
			self._file = File(self._core, self._base)
		return self._file

	def clone(self) -> 'Mode':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mode(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trace:
	"""Trace commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trace", core, parent)

	def set(self, trace_enable: bool, trace: enums.TraceC) -> None:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:ACP:TRACe \n
		Snippet: driver.display.gprfMeasurement.acp.trace.set(trace_enable = False, trace = enums.TraceC.AVERage) \n
		Selects which set of results is displayed on the 'ACP' tab. Only one set of results is displayed at a time. Enabling one
		set disables the others. \n
			:param trace_enable: OFF | ON Disables or enables the set selected via Trace
			:param trace: CURRent | AVERage | MAXimum Selects the set of results to be enabled/disabled
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('trace_enable', trace_enable, DataType.Boolean), ArgSingle('trace', trace, DataType.Enum))
		self._core.io.write(f'DISPlay:GPRF:MEASurement<Instance>:ACP:TRACe {param}'.rstrip())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Socket:
	"""Socket commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("socket", core, parent)

	def get_vresource(self) -> str:
		"""SCPI: SYSTem:COMMunicate:SOCKet:VRESource \n
		Snippet: value: str = driver.system.communicate.socket.get_vresource() \n
		Queries the VISA resource string of the socket resource (direct socket communication) . \n
			:return: visa_resource: VISA resource string
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SOCKet:VRESource?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ProtocolMode:
		"""SCPI: SYSTem:COMMunicate:SOCKet:MODE \n
		Snippet: value: enums.ProtocolMode = driver.system.communicate.socket.get_mode() \n
		Sets the protocol operation mode for direct socket communication. \n
			:return: protocol_mode: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SOCKet:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ProtocolMode)

	def set_mode(self, protocol_mode: enums.ProtocolMode) -> None:
		"""SCPI: SYSTem:COMMunicate:SOCKet:MODE \n
		Snippet: driver.system.communicate.socket.set_mode(protocol_mode = enums.ProtocolMode.AGILent) \n
		Sets the protocol operation mode for direct socket communication. \n
			:param protocol_mode: RAW | AGILent | IEEE1174 RAW No support of control messages AGILent Emulation codes via control connection (control port) IEEE1174 Emulation codes via data connection (data port)
		"""
		param = Conversions.enum_scalar_to_str(protocol_mode, enums.ProtocolMode)
		self._core.io.write(f'SYSTem:COMMunicate:SOCKet:MODE {param}')

	def get_port(self) -> int:
		"""SCPI: SYSTem:COMMunicate:SOCKet:PORT \n
		Snippet: value: int = driver.system.communicate.socket.get_port() \n
		Sets the data port number for direct socket communication. \n
			:return: port_number: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:SOCKet:PORT?')
		return Conversions.str_to_int(response)

	def set_port(self, port_number: int) -> None:
		"""SCPI: SYSTem:COMMunicate:SOCKet:PORT \n
		Snippet: driver.system.communicate.socket.set_port(port_number = 1) \n
		Sets the data port number for direct socket communication. \n
			:param port_number: To select a free port number, enter 0. To select a specific port number, use the following range. Range: 1024 to 32767
		"""
		param = Conversions.decimal_value_to_str(port_number)
		self._core.io.write(f'SYSTem:COMMunicate:SOCKet:PORT {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fmoddepth:
	"""Fmoddepth commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fmoddepth", core, parent)

	def get(self, frequencyLobe=repcap.FrequencyLobe.Nr1) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FMODdepth<nr> \n
		Snippet: value: float = driver.source.avionics.generator.ils.localizer.afSettings.fmoddepth.get(frequencyLobe = repcap.FrequencyLobe.Nr1) \n
		Queries the modulation depth for one lobe. \n
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1
			:return: freq_1: Range: 0 % to 100 %, Unit: %"""
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		response = self._core.io.query_str(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FMODdepth{frequencyLobe_cmd_val}?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dialing:
	"""Dialing commands group definition. 34 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dialing", core, parent)

	@property
	def scal(self):
		"""scal commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_scal'):
			from .Dialing_.Scal import Scal
			self._scal = Scal(self._core, self._base)
		return self._scal

	@property
	def dtmf(self):
		"""dtmf commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_dtmf'):
			from .Dialing_.Dtmf import Dtmf
			self._dtmf = Dtmf(self._core, self._base)
		return self._dtmf

	@property
	def fdialing(self):
		"""fdialing commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_fdialing'):
			from .Dialing_.Fdialing import Fdialing
			self._fdialing = Fdialing(self._core, self._base)
		return self._fdialing

	@property
	def selCall(self):
		"""selCall commands group. 2 Sub-classes, 7 commands."""
		if not hasattr(self, '_selCall'):
			from .Dialing_.SelCall import SelCall
			self._selCall = SelCall(self._core, self._base)
		return self._selCall

	def clone(self) -> 'Dialing':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dialing(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limit:
	"""Limit commands group definition. 8 total commands, 4 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("limit", core, parent)

	@property
	def rsensitivity(self):
		"""rsensitivity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsensitivity'):
			from .Limit_.Rsensitivity import Rsensitivity
			self._rsensitivity = Rsensitivity(self._core, self._base)
		return self._rsensitivity

	@property
	def rifBandwidth(self):
		"""rifBandwidth commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rifBandwidth'):
			from .Limit_.RifBandwidth import RifBandwidth
			self._rifBandwidth = RifBandwidth(self._core, self._base)
		return self._rifBandwidth

	@property
	def rsquelch(self):
		"""rsquelch commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rsquelch'):
			from .Limit_.Rsquelch import Rsquelch
			self._rsquelch = Rsquelch(self._core, self._base)
		return self._rsquelch

	@property
	def tsensitivity(self):
		"""tsensitivity commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tsensitivity'):
			from .Limit_.Tsensitivity import Tsensitivity
			self._tsensitivity = Tsensitivity(self._core, self._base)
		return self._tsensitivity

	# noinspection PyTypeChecker
	class SsnrStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON
			- Upper: float: Unit: dB
			- Lower: float: Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper'),
			ArgStruct.scalar_float('Lower')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None
			self.Lower: float = None

	def get_ssnr(self) -> SsnrStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:SSNR \n
		Snippet: value: SsnrStruct = driver.configure.afRf.measurement.searchRoutines.limit.get_ssnr() \n
		Enables a limit check and sets limits for the determined SNR. \n
			:return: structure: for return value, see the help for SsnrStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:SSNR?', self.__class__.SsnrStruct())

	def set_ssnr(self, value: SsnrStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:SSNR \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.set_ssnr(value = SsnrStruct()) \n
		Enables a limit check and sets limits for the determined SNR. \n
			:param value: see the help for SsnrStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:SSNR', value)

	def clone(self) -> 'Limit':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Limit(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	def clear(self) -> None:
		"""SCPI: TRACe:REMote:MODE:DISPlay:CLEar \n
		Snippet: driver.trace.remote.mode.display.clear() \n
		Clears the display of the SCPI remote trace in analysis mode. \n
		"""
		self._core.io.write(f'TRACe:REMote:MODE:DISPlay:CLEar')

	def clear_with_opc(self) -> None:
		"""SCPI: TRACe:REMote:MODE:DISPlay:CLEar \n
		Snippet: driver.trace.remote.mode.display.clear_with_opc() \n
		Clears the display of the SCPI remote trace in analysis mode. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'TRACe:REMote:MODE:DISPlay:CLEar')
